@@ -27,19 +27,18 @@
 #include "dom/dom_string.h"
 #include "imload/imagemanager.h"
 #include "khtmlview.h"
-#include <QtCore/QCharRef>
-#include <QtCore/QVariant>
-#include <QtCore/QMap>
-#include <QtCore/QTimer>
+#include <QCharRef>
+#include <QVariant>
+#include <QMap>
+#include <QTimer>
 #include <QImageReader>
 
-#include <QDebug>
+#include "khtml_debug.h"
 #include <kmessagebox.h>
 #include <qmimedatabase.h>
 
 #include "xml/dom_docimpl.h"
 #include "css/cssstyleselector.h"
-#include "css/csshelper.h"
 #include "css/cssproperties.h"
 #include "css/cssvalues.h"
 #include "rendering/render_frames.h"
@@ -53,7 +52,7 @@ HTMLPartContainerElementImpl::HTMLPartContainerElementImpl(DocumentImpl *doc)
     : HTMLElementImpl(doc)
 {
     m_needToComputeContent = true;
-    m_childWidget          = 0;
+    m_childWidget          = nullptr;
 }
 
 HTMLPartContainerElementImpl::~HTMLPartContainerElementImpl()
@@ -125,7 +124,7 @@ void HTMLPartContainerElementImpl::partLoadingErrorNotify()
 
 void HTMLPartContainerElementImpl::clearChildWidget()
 {
-    setWidget(0);
+    setWidget(nullptr);
 }
 
 bool HTMLPartContainerElementImpl::mimetypeHandledInternally(const QString &)
@@ -145,7 +144,7 @@ void HTMLPartContainerElementImpl::postResizeEvent()
 
 void HTMLPartContainerElementImpl::sendPostedResizeEvents()
 {
-    QApplication::sendPostedEvents(0, DOMCFResizeEvent);
+    QApplication::sendPostedEvents(nullptr, DOMCFResizeEvent);
 }
 
 bool HTMLPartContainerElementImpl::event(QEvent *e)
@@ -350,7 +349,7 @@ HTMLEmbedElementImpl *HTMLObjectBaseElementImpl::relevantEmbed()
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 bool HTMLObjectBaseElementImpl::mimetypeHandledInternally(const QString &mime)
@@ -480,7 +479,7 @@ void HTMLObjectBaseElementImpl::computeContent()
                      classId.indexOf(QString::fromLatin1("22D6f312-B0F6-11D0-94AB-0080C74C7E95")) >= 0) {
                 effectiveServiceType = "video/x-msvideo";
             } else {
-                // qDebug() << "ActiveX classId " << classId;
+                // qCDebug(KHTML_LOG) << "ActiveX classId " << classId;
             }
             // TODO: add more plugins here
         }
@@ -552,7 +551,7 @@ void HTMLObjectBaseElementImpl::computeContent()
     KHTMLPart *part = document()->part();
     clearChildWidget();
 
-    // qDebug() << effectiveURL << effectiveServiceType << params;
+    // qCDebug(KHTML_LOG) << effectiveURL << effectiveServiceType << params;
 
     if (!part->loadObjectElement(this, effectiveURL, effectiveServiceType, params)) {
         // Looks like we are gonna need alternative content after all...
@@ -629,10 +628,10 @@ void HTMLObjectBaseElementImpl::slotPartLoadingErrorNotify()
             // Prepare the URL to show in the question (host only if http, to make it short)
             QUrl pluginPageURL(embed->pluginPage);
             QString shortURL = pluginPageURL.scheme() == "http" ? pluginPageURL.host() : pluginPageURL.toDisplayString();
-            int res = KMessageBox::questionYesNo(part->view(),
-                                                 i18n("No plugin found for '%1'.\nDo you want to download one from %2?", mimeName, shortURL),
-                                                 i18n("Missing Plugin"), KGuiItem(i18n("Download")), KGuiItem(i18n("Do Not Download")), QString("plugin-") + serviceType);
-            if (res == KMessageBox::Yes) {
+            int res = KMessageBox::questionTwoActions(part->view(),
+                                                      i18n("No plugin found for '%1'.\nDo you want to download one from %2?", mimeName, shortURL),
+                                                      i18n("Missing Plugin"), KGuiItem(i18n("Download")), KGuiItem(i18n("Do Not Download")), QString("plugin-") + serviceType);
+            if (res == KMessageBox::PrimaryAction) {
                 // Display vendor download page
                 ext->createNewWindow(pluginPageURL);
                 return;
@@ -725,7 +724,7 @@ void HTMLEmbedElementImpl::parseAttribute(AttributeImpl *attr)
     switch (attr->id()) {
     case ATTR_CODE:
     case ATTR_SRC:
-        url = khtml::parseURL(attr->val()).string();
+        url = attr->value().trimSpaces().string();
         setNeedComputeContent();
         break;
     case ATTR_BORDER:
@@ -800,14 +799,14 @@ NodeImpl::Id HTMLObjectElementImpl::id() const
 
 HTMLFormElementImpl *HTMLObjectElementImpl::form() const
 {
-    return 0;
+    return nullptr;
 }
 
 void HTMLObjectElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch (attr->id()) {
     case ATTR_DATA:
-        url = khtml::parseURL(attr->val()).string();
+        url = attr->value().trimSpaces().string();
         setNeedComputeContent();
         break;
     case ATTR_CLASSID:
@@ -847,7 +846,7 @@ DocumentImpl *HTMLObjectElementImpl::contentDocument() const
     if (widget && qobject_cast<KHTMLView *>(widget)) {
         return static_cast<KHTMLView *>(widget)->part()->xmlDocImpl();
     }
-    return 0;
+    return nullptr;
 }
 
 void HTMLObjectElementImpl::attach()
